@@ -11,7 +11,7 @@ Term::Shell::MultiCmd -  Nested Commands Tree in Shell Interface
 
 =cut
 
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 
 =head1 SYNOPSIS
 
@@ -167,7 +167,7 @@ sub _travela($@) {              # explicit array
 
 sub _travel($$) {
     my ($o, $c) = &_check_pager ; # clear $c pager sign, let cmd know about it.
-    $c = _check_inner_alias($o, $c);
+    $c = _check_silent_aliases($o, $c);
     _travela( $o, _split $o, $c )
 }
 
@@ -875,22 +875,23 @@ sub _check_pager {
     ($o, $c)
 }
 
-sub _check_inner_alias {
-    my ($o, $c) = @_ ;
-    my $d = $o->{delimiterRE};
+sub _check_silent_aliases {
+    my ($o, $cmd) = @_ ;
+    return  $cmd unless $cmd;
     my $r = $o->{root} || $o->{cmds};
-    if ($o->{root_cmd} and
-        not exists $r->{cd} ) {
+    my ($c, @a) = _split $o, $cmd;
 
-        return _join $o, $o->{root_cmd}, '-clear'   if $c =~ /^cd$/;
-        return _join $o, $o->{root_cmd}, '-set', $1 if $c =~ /^cd$d(.*)$/;
-    }
-    if ($o->{help_cmd} and
-        not exists $r->{ls} ) {
-        return _join $o, $o->{help_cmd}     if $c =~ /^ls$/;
-        return _join $o, $o->{help_cmd}, $1 if $c =~ /^ls$d(.*)/ ;
-    }
-    $c
+    return _join $o, $o->{root_cmd}, (@a ? (-set => @a ) : ('-clear'))
+      if ( $c eq 'cd' and
+           $o->{root_cmd} and
+           not exists $r->{cd});
+
+    return _join $o, $o->{help_cmd}, @a
+      if $o->{help_cmd} and
+        ( ($c eq 'ls'   and not exists $r->{ls}  ) or
+          ($c eq 'help' and not exists $r->{help}) );
+
+    $cmd
 }
 
 =head2 cmd
